diff --git a/FHEM/09_CUL_FHTTK.pm b/FHEM/09_CUL_FHTTK.pm
index c54b8a023..1c8c6ca45 100644
--- a/FHEM/09_CUL_FHTTK.pm
+++ b/FHEM/09_CUL_FHTTK.pm
@@ -100,7 +100,7 @@ my %fhttfk_c2b; # command->button hash
my %canset = (
"01" => "Open",
"02" => "Closed",
- "0c" => "Syncing",
+ "0c" => "Pair",
"ff" => "ReSync");
# -wusel, 2009-11-06
@@ -178,8 +178,8 @@ CUL_FHTTK_Set($@)
IOWrite($hash, "", sprintf("T%s02", $hash->{CODE})); # 0x02 - closed or 0x82
- } elsif($opt eq "Syncing" ) {
- Log3 $name, 3, "CUL_FHTTK ($name) syncing with FHT80b.";
+ } elsif($opt eq "Pair" ) {
+ Log3 $name, 3, "CUL_FHTTK ($name) pairing with FHT80b.";
IOWrite($hash, "", sprintf("T%s0c", $hash->{CODE})); # 0x0c - sync
# window state switch to closed through cul FW implementation
@@ -189,9 +189,11 @@ CUL_FHTTK_Set($@)
Log3 $name, 3, "CUL_FHTTK ($name) resyncing with FHT80b.";
IOWrite($hash, "", sprintf("T%s%s", $hash->{CODE}, $fhttfk_c2b{$opt})); # 0xff - ReSync
+ # window state switch to closed through cul FW implementation
+ $opt = "Closed";
} else {
- return "Unknown argument $a[1], choose one of Syncing Open Closed"
+ return "Unknown argument $a[1], choose one of Pair ReSync Open Closed"
}
# update new state
@@ -316,9 +318,9 @@ CUL_FHTTK_Parse($$)
}
# Flag the battery warning separately
if($state eq "11" || $state eq "12") {
- readingsBulkUpdate($def, "Battery", "Low");
+ readingsBulkUpdate($def, "Battery", "Low");
} else {
- readingsBulkUpdate($def, "Battery", "ok");
+ readingsBulkUpdate($def, "Battery", "ok");
}
#CHANGED
readingsBulkUpdate($def, "state", $val);
@@ -386,11 +388,12 @@ CUL_FHTTK_Parse($$)
where value
is one of:
- Syncing # start the sync with FHT80B (activate FHT80B sync mode before) - state after syncing is Closed
- Closed # set window state to Closed
- Open # set window state to Open
- ReSync # resync virtual sensor with FHT80b after a reset of CUL device. In other words, perform a virtual
- battery exchange to synchronize the sensor with FHT80b device again.
+ Pair # start pairing with FHT80B (activate FHT80B sync mode before) - state after pairing is Closed
+ Closed # set window state to Closed
+ Open # set window state to Open
+ ReSync # resync virtual sensor with FHT80b after a reset of CUL device. In other words, perform a virtual
+ battery exchange to synchronize the sensor with FHT80b device again. (at the moment, only
+ available with prototype cul_fw - see forum 55774)
value
folgendes sein kann:
- Syncing # startet die Synchronisation mit dem FHT80B (FHT80B muss sich im Sync mode befinden) - danach wird der state auf "Closed" gesetzt
- Closed # setzt den Fensterstatus zu Closed
- Open # setzt den Fensterstatus zu Open
- ReSync # neu synchronisieren des virtuellen Sensor mit dem FHT80b Module. Damit wird ein virtueller Batteriewechsel symuliert und der angelernte
- Sensor wieder aufsynchronisiert.
+ Pair # startet das Anlernen an das FHT80B (FHT80B muss sich im Sync mode befinden) - danach wird der state auf "Closed" gesetzt
+ Closed # setzt den Fensterstatus zu Closed
+ Open # setzt den Fensterstatus zu Open
+ ReSync # neu synchronisieren des virtuellen Sensor mit dem FHT80b Module. Damit wird ein virtueller Batteriewechsel symuliert und der angelernte
+ Sensor wieder aufsynchronisiert. (aktuell nur mit Prototyp CUL FW verfügbar Forum 55774)